@@ -70,6 +70,35 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/recentOrders-GET': {
+        'parameters': [
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'only_executed'
+            },
+        ]
+    },
+    '/accounts/{accountId}/returnRates-GET': {
+        'parameters': [
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+        ]
+    },
     '/accounts/{accountId}/holdings-GET': {
         'parameters': [
             {
@@ -228,6 +257,19 @@ operation_parameter_map = {
             },
         ]
     },
+    '/authorizations/{authorizationId}/returnRates-GET': {
+        'parameters': [
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'authorizationId'
+            },
+        ]
+    },
     '/sessionEvents-GET': {
         'parameters': [
             {
